"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SparkOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVER_CPU_FIELD_NUMBER: builtins.int
    DRIVER_MEMORY_FIELD_NUMBER: builtins.int
    EXECUTOR_CPU_FIELD_NUMBER: builtins.int
    EXECUTOR_MEMORY_FIELD_NUMBER: builtins.int
    driver_cpu: builtins.int
    """Override CPU requested for driver"""
    driver_memory: builtins.str
    """Override memory requested for driver"""
    executor_cpu: builtins.int
    """Override CPU requested for executor"""
    executor_memory: builtins.str
    """Override memory requested for executor"""
    def __init__(
        self,
        *,
        driver_cpu: builtins.int = ...,
        driver_memory: builtins.str = ...,
        executor_cpu: builtins.int = ...,
        executor_memory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_cpu", b"driver_cpu", "driver_memory", b"driver_memory", "executor_cpu", b"executor_cpu", "executor_memory", b"executor_memory"]) -> None: ...

global___SparkOverride = SparkOverride
