# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast/core/CoreService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from feast.core import Entity_pb2 as feast_dot_core_dot_Entity__pb2
from feast.core import Feature_pb2 as feast_dot_core_dot_Feature__pb2
from feast.core import FeatureTable_pb2 as feast_dot_core_dot_FeatureTable__pb2
from feast.core import OnlineStore_pb2 as feast_dot_core_dot_OnlineStore__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66\x65\x61st/core/CoreService.proto\x12\nfeast.core\x1a\x17\x66\x65\x61st/core/Entity.proto\x1a\x18\x66\x65\x61st/core/Feature.proto\x1a\x1d\x66\x65\x61st/core/FeatureTable.proto\x1a\x1c\x66\x65\x61st/core/OnlineStore.proto\"1\n\x10GetEntityRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\"7\n\x11GetEntityResponse\x12\"\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x12.feast.core.Entity\"\xdc\x01\n\x13ListEntitiesRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.feast.core.ListEntitiesRequest.Filter\x1a\x8c\x01\n\x06\x46ilter\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x42\n\x06labels\x18\x04 \x03(\x0b\x32\x32.feast.core.ListEntitiesRequest.Filter.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x14ListEntitiesResponse\x12$\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x12.feast.core.Entity\"\xee\x01\n\x13ListFeaturesRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.feast.core.ListFeaturesRequest.Filter\x1a\x9e\x01\n\x06\x46ilter\x12\x42\n\x06labels\x18\x01 \x03(\x0b\x32\x32.feast.core.ListFeaturesRequest.Filter.LabelsEntry\x12\x10\n\x08\x65ntities\x18\x02 \x03(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\x14ListFeaturesResponse\x12@\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32..feast.core.ListFeaturesResponse.FeaturesEntry\x1aH\n\rFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.feast.core.FeatureSpec:\x02\x38\x01J\x04\x08\x01\x10\x02\"K\n\x12\x41pplyEntityRequest\x12$\n\x04spec\x18\x01 \x01(\x0b\x32\x16.feast.core.EntitySpec\x12\x0f\n\x07project\x18\x02 \x01(\t\"9\n\x13\x41pplyEntityResponse\x12\"\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x12.feast.core.Entity\"\x1c\n\x1aGetFeastCoreVersionRequest\".\n\x1bGetFeastCoreVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"$\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x17\n\x15\x43reateProjectResponse\"%\n\x15\x41rchiveProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16\x41rchiveProjectResponse\"\x15\n\x13ListProjectsRequest\"(\n\x14ListProjectsResponse\x12\x10\n\x08projects\x18\x01 \x03(\t\"]\n\x18\x41pplyFeatureTableRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x30\n\ntable_spec\x18\x02 \x01(\x0b\x32\x1c.feast.core.FeatureTableSpec\"D\n\x19\x41pplyFeatureTableResponse\x12\'\n\x05table\x18\x01 \x01(\x0b\x32\x18.feast.core.FeatureTable\"7\n\x16GetFeatureTableRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"B\n\x17GetFeatureTableResponse\x12\'\n\x05table\x18\x01 \x01(\x0b\x32\x18.feast.core.FeatureTable\"\xeb\x01\n\x18ListFeatureTablesRequest\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.feast.core.ListFeatureTablesRequest.Filter\x1a\x91\x01\n\x06\x46ilter\x12\x0f\n\x07project\x18\x01 \x01(\t\x12G\n\x06labels\x18\x03 \x03(\x0b\x32\x37.feast.core.ListFeatureTablesRequest.Filter.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x19ListFeatureTablesResponse\x12(\n\x06tables\x18\x01 \x03(\x0b\x32\x18.feast.core.FeatureTable\":\n\x19\x44\x65leteFeatureTableRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteFeatureTableResponse\"\x19\n\x17ListOnlineStoresRequest\"I\n\x18ListOnlineStoresResponse\x12-\n\x0conline_store\x18\x01 \x03(\x0b\x32\x17.feast.core.OnlineStore\"%\n\x15GetOnlineStoreRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa6\x01\n\x16GetOnlineStoreResponse\x12-\n\x0conline_store\x18\x01 \x01(\x0b\x32\x17.feast.core.OnlineStore\x12\x39\n\x06status\x18\x02 \x01(\x0e\x32).feast.core.GetOnlineStoreResponse.Status\"\"\n\x06Status\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08\x41RCHIVED\x10\x01\"K\n\x1aRegisterOnlineStoreRequest\x12-\n\x0conline_store\x18\x01 \x01(\x0b\x32\x17.feast.core.OnlineStore\"\xc2\x01\n\x1bRegisterOnlineStoreResponse\x12-\n\x0conline_store\x18\x01 \x01(\x0b\x32\x17.feast.core.OnlineStore\x12>\n\x06status\x18\x02 \x01(\x0e\x32..feast.core.RegisterOnlineStoreResponse.Status\"4\n\x06Status\x12\r\n\tNO_CHANGE\x10\x00\x12\x0e\n\nREGISTERED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\")\n\x19\x41rchiveOnlineStoreRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1c\n\x1a\x41rchiveOnlineStoreResponse2\xc1\x0b\n\x0b\x43oreService\x12\x66\n\x13GetFeastCoreVersion\x12&.feast.core.GetFeastCoreVersionRequest\x1a\'.feast.core.GetFeastCoreVersionResponse\x12H\n\tGetEntity\x12\x1c.feast.core.GetEntityRequest\x1a\x1d.feast.core.GetEntityResponse\x12Q\n\x0cListFeatures\x12\x1f.feast.core.ListFeaturesRequest\x1a .feast.core.ListFeaturesResponse\x12N\n\x0b\x41pplyEntity\x12\x1e.feast.core.ApplyEntityRequest\x1a\x1f.feast.core.ApplyEntityResponse\x12Q\n\x0cListEntities\x12\x1f.feast.core.ListEntitiesRequest\x1a .feast.core.ListEntitiesResponse\x12T\n\rCreateProject\x12 .feast.core.CreateProjectRequest\x1a!.feast.core.CreateProjectResponse\x12W\n\x0e\x41rchiveProject\x12!.feast.core.ArchiveProjectRequest\x1a\".feast.core.ArchiveProjectResponse\x12Q\n\x0cListProjects\x12\x1f.feast.core.ListProjectsRequest\x1a .feast.core.ListProjectsResponse\x12`\n\x11\x41pplyFeatureTable\x12$.feast.core.ApplyFeatureTableRequest\x1a%.feast.core.ApplyFeatureTableResponse\x12`\n\x11ListFeatureTables\x12$.feast.core.ListFeatureTablesRequest\x1a%.feast.core.ListFeatureTablesResponse\x12Z\n\x0fGetFeatureTable\x12\".feast.core.GetFeatureTableRequest\x1a#.feast.core.GetFeatureTableResponse\x12\x63\n\x12\x44\x65leteFeatureTable\x12%.feast.core.DeleteFeatureTableRequest\x1a&.feast.core.DeleteFeatureTableResponse\x12]\n\x10ListOnlineStores\x12#.feast.core.ListOnlineStoresRequest\x1a$.feast.core.ListOnlineStoresResponse\x12W\n\x0eGetOnlineStore\x12!.feast.core.GetOnlineStoreRequest\x1a\".feast.core.GetOnlineStoreResponse\x12\x66\n\x13RegisterOnlineStore\x12&.feast.core.RegisterOnlineStoreRequest\x1a\'.feast.core.RegisterOnlineStoreResponse\x12\x63\n\x12\x41rchiveOnlineStore\x12%.feast.core.ArchiveOnlineStoreRequest\x1a&.feast.core.ArchiveOnlineStoreResponseB|\n\x1e\x64\x65v.caraml.store.protobuf.coreB\x10\x43oreServiceProtoZHgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/coreb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast.core.CoreService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036dev.caraml.store.protobuf.coreB\020CoreServiceProtoZHgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/core'
  _LISTENTITIESREQUEST_FILTER_LABELSENTRY._options = None
  _LISTENTITIESREQUEST_FILTER_LABELSENTRY._serialized_options = b'8\001'
  _LISTFEATURESREQUEST_FILTER_LABELSENTRY._options = None
  _LISTFEATURESREQUEST_FILTER_LABELSENTRY._serialized_options = b'8\001'
  _LISTFEATURESRESPONSE_FEATURESENTRY._options = None
  _LISTFEATURESRESPONSE_FEATURESENTRY._serialized_options = b'8\001'
  _LISTFEATURETABLESREQUEST_FILTER_LABELSENTRY._options = None
  _LISTFEATURETABLESREQUEST_FILTER_LABELSENTRY._serialized_options = b'8\001'
  _GETENTITYREQUEST._serialized_start=156
  _GETENTITYREQUEST._serialized_end=205
  _GETENTITYRESPONSE._serialized_start=207
  _GETENTITYRESPONSE._serialized_end=262
  _LISTENTITIESREQUEST._serialized_start=265
  _LISTENTITIESREQUEST._serialized_end=485
  _LISTENTITIESREQUEST_FILTER._serialized_start=345
  _LISTENTITIESREQUEST_FILTER._serialized_end=485
  _LISTENTITIESREQUEST_FILTER_LABELSENTRY._serialized_start=440
  _LISTENTITIESREQUEST_FILTER_LABELSENTRY._serialized_end=485
  _LISTENTITIESRESPONSE._serialized_start=487
  _LISTENTITIESRESPONSE._serialized_end=547
  _LISTFEATURESREQUEST._serialized_start=550
  _LISTFEATURESREQUEST._serialized_end=788
  _LISTFEATURESREQUEST_FILTER._serialized_start=630
  _LISTFEATURESREQUEST_FILTER._serialized_end=788
  _LISTFEATURESREQUEST_FILTER_LABELSENTRY._serialized_start=440
  _LISTFEATURESREQUEST_FILTER_LABELSENTRY._serialized_end=485
  _LISTFEATURESRESPONSE._serialized_start=791
  _LISTFEATURESRESPONSE._serialized_end=959
  _LISTFEATURESRESPONSE_FEATURESENTRY._serialized_start=881
  _LISTFEATURESRESPONSE_FEATURESENTRY._serialized_end=953
  _APPLYENTITYREQUEST._serialized_start=961
  _APPLYENTITYREQUEST._serialized_end=1036
  _APPLYENTITYRESPONSE._serialized_start=1038
  _APPLYENTITYRESPONSE._serialized_end=1095
  _GETFEASTCOREVERSIONREQUEST._serialized_start=1097
  _GETFEASTCOREVERSIONREQUEST._serialized_end=1125
  _GETFEASTCOREVERSIONRESPONSE._serialized_start=1127
  _GETFEASTCOREVERSIONRESPONSE._serialized_end=1173
  _CREATEPROJECTREQUEST._serialized_start=1175
  _CREATEPROJECTREQUEST._serialized_end=1211
  _CREATEPROJECTRESPONSE._serialized_start=1213
  _CREATEPROJECTRESPONSE._serialized_end=1236
  _ARCHIVEPROJECTREQUEST._serialized_start=1238
  _ARCHIVEPROJECTREQUEST._serialized_end=1275
  _ARCHIVEPROJECTRESPONSE._serialized_start=1277
  _ARCHIVEPROJECTRESPONSE._serialized_end=1301
  _LISTPROJECTSREQUEST._serialized_start=1303
  _LISTPROJECTSREQUEST._serialized_end=1324
  _LISTPROJECTSRESPONSE._serialized_start=1326
  _LISTPROJECTSRESPONSE._serialized_end=1366
  _APPLYFEATURETABLEREQUEST._serialized_start=1368
  _APPLYFEATURETABLEREQUEST._serialized_end=1461
  _APPLYFEATURETABLERESPONSE._serialized_start=1463
  _APPLYFEATURETABLERESPONSE._serialized_end=1531
  _GETFEATURETABLEREQUEST._serialized_start=1533
  _GETFEATURETABLEREQUEST._serialized_end=1588
  _GETFEATURETABLERESPONSE._serialized_start=1590
  _GETFEATURETABLERESPONSE._serialized_end=1656
  _LISTFEATURETABLESREQUEST._serialized_start=1659
  _LISTFEATURETABLESREQUEST._serialized_end=1894
  _LISTFEATURETABLESREQUEST_FILTER._serialized_start=1749
  _LISTFEATURETABLESREQUEST_FILTER._serialized_end=1894
  _LISTFEATURETABLESREQUEST_FILTER_LABELSENTRY._serialized_start=440
  _LISTFEATURETABLESREQUEST_FILTER_LABELSENTRY._serialized_end=485
  _LISTFEATURETABLESRESPONSE._serialized_start=1896
  _LISTFEATURETABLESRESPONSE._serialized_end=1965
  _DELETEFEATURETABLEREQUEST._serialized_start=1967
  _DELETEFEATURETABLEREQUEST._serialized_end=2025
  _DELETEFEATURETABLERESPONSE._serialized_start=2027
  _DELETEFEATURETABLERESPONSE._serialized_end=2055
  _LISTONLINESTORESREQUEST._serialized_start=2057
  _LISTONLINESTORESREQUEST._serialized_end=2082
  _LISTONLINESTORESRESPONSE._serialized_start=2084
  _LISTONLINESTORESRESPONSE._serialized_end=2157
  _GETONLINESTOREREQUEST._serialized_start=2159
  _GETONLINESTOREREQUEST._serialized_end=2196
  _GETONLINESTORERESPONSE._serialized_start=2199
  _GETONLINESTORERESPONSE._serialized_end=2365
  _GETONLINESTORERESPONSE_STATUS._serialized_start=2331
  _GETONLINESTORERESPONSE_STATUS._serialized_end=2365
  _REGISTERONLINESTOREREQUEST._serialized_start=2367
  _REGISTERONLINESTOREREQUEST._serialized_end=2442
  _REGISTERONLINESTORERESPONSE._serialized_start=2445
  _REGISTERONLINESTORERESPONSE._serialized_end=2639
  _REGISTERONLINESTORERESPONSE_STATUS._serialized_start=2587
  _REGISTERONLINESTORERESPONSE_STATUS._serialized_end=2639
  _ARCHIVEONLINESTOREREQUEST._serialized_start=2641
  _ARCHIVEONLINESTOREREQUEST._serialized_end=2682
  _ARCHIVEONLINESTORERESPONSE._serialized_start=2684
  _ARCHIVEONLINESTORERESPONSE._serialized_end=2712
  _CORESERVICE._serialized_start=2715
  _CORESERVICE._serialized_end=4188
# @@protoc_insertion_point(module_scope)
