# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast/core/DataFormat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66\x65\x61st/core/DataFormat.proto\x12\nfeast.core\"g\n\nFileFormat\x12>\n\x0eparquet_format\x18\x01 \x01(\x0b\x32$.feast.core.FileFormat.ParquetFormatH\x00\x1a\x0f\n\rParquetFormatB\x08\n\x06\x66ormat\"\xd8\x01\n\x0cStreamFormat\x12:\n\x0b\x61vro_format\x18\x01 \x01(\x0b\x32#.feast.core.StreamFormat.AvroFormatH\x00\x12<\n\x0cproto_format\x18\x02 \x01(\x0b\x32$.feast.core.StreamFormat.ProtoFormatH\x00\x1a!\n\x0bProtoFormat\x12\x12\n\nclass_path\x18\x01 \x01(\t\x1a!\n\nAvroFormat\x12\x13\n\x0bschema_json\x18\x01 \x01(\tB\x08\n\x06\x66ormatB{\n\x1e\x64\x65v.caraml.store.protobuf.coreB\x0f\x44\x61taFormatProtoZHgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/coreb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast.core.DataFormat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036dev.caraml.store.protobuf.coreB\017DataFormatProtoZHgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/core'
  _FILEFORMAT._serialized_start=43
  _FILEFORMAT._serialized_end=146
  _FILEFORMAT_PARQUETFORMAT._serialized_start=121
  _FILEFORMAT_PARQUETFORMAT._serialized_end=136
  _STREAMFORMAT._serialized_start=149
  _STREAMFORMAT._serialized_end=365
  _STREAMFORMAT_PROTOFORMAT._serialized_start=287
  _STREAMFORMAT_PROTOFORMAT._serialized_end=320
  _STREAMFORMAT_AVROFORMAT._serialized_start=322
  _STREAMFORMAT_AVROFORMAT._serialized_end=355
# @@protoc_insertion_point(module_scope)
